@@ -1,12 +1,11 @@
 package App::Cpan;
 
-use v5.10.1;
-
+use 5.006;
 use strict;
 use warnings;
 use vars qw($VERSION);
 
-$VERSION = '1.58_01';
+$VERSION = '1.59_02';
 
 =head1 NAME
 
@@ -357,8 +356,9 @@ sub _process_setup_options
 	else
 		{
 		# this is what CPAN.pm would do otherwise
+		local $CPAN::Be_Silent = 1;
 		CPAN::HandleConfig->load(
-			be_silent  => 1,
+			# be_silent  => 1, deprecated
 			write_file => 0,
 			);
 		}
@@ -449,7 +449,8 @@ sub run
 	}
 
 {
-package Local::Null::Logger;
+package
+  Local::Null::Logger; # hide from PAUSE
 
 sub new { bless \ my $x, $_[0] }
 sub AUTOLOAD { 1 }
@@ -755,11 +756,12 @@ Stolen from File::Path::Expand
 
 sub _expand_filename
 	{
-    my( $path )= @_;
-    print STDERR "\tExpanding $path\n";
+    my( $path ) = @_;
+    no warnings 'uninitialized';
+    $logger->debug( "Expanding path $path\n" );
     $path =~ s{\A~([^/]+)?}{
-		_home_of( $1 || $> ) || ${^MATCH}
-    	}pe;
+		_home_of( $1 || $> ) || "~$1"
+    	}e;
     return $path;
 	}
 
@@ -1274,8 +1276,10 @@ sub _eval_version
 	{
 	my( $line, $sigil, $var ) = @_;
 
+        # split package line to hide from PAUSE
 	my $eval = qq{
-		package ExtUtils::MakeMaker::_version;
+		package
+                  ExtUtils::MakeMaker::_version;
 
 		local $sigil$var;
 		\$$var=undef; do {
